@@ -4,7 +4,7 @@ use warnings;
 use Any::Moose;
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has max_rate => (
     is      => 'rw',
@@ -18,6 +18,11 @@ has rand_func => (
     },
 );
 
+has sort => (
+    is      => 'rw',
+    default => 0,
+);
+
 has _func => (
     is      => 'rw',
     default => sub { [] },
@@ -51,7 +56,8 @@ sub add {
 sub generate {
     my ($self) = @_;
 
-    my @sorted_funcs = sort { $a->[0] <=> $b->[0] } @{ $self->_func };
+    my @sorted_funcs = @{ $self->_func };
+    @sorted_funcs = sort { $a->[0] <=> $b->[0] } @sorted_funcs if $self->sort;
 
     my $rand         = $self->rand_func;
     my $max_rate     = $self->max_rate;
